/*
 * M0110 keymap
 */
KEYBOARD_ID = "m0110";

/* for ATMega32U4 with 32KB flash */
KEYMAP_START_ADDRESS = 0x6800;

/* Key matrix: Row:14 * Col:8
 *   COL 0     1       2       3       4       5       6       7
 * ROW,---------------------------------------------------------------
 *   0|  00    01      02      03      04      05      06      07
 *   1|  08    09      0A      0B      0C      0D      0E      0F
 *   2|  10    11      12      13      14      15      16      17
 *   3|  18    19      1A      1B      1C      1D      1E      1F
 *   4|  20    21      22      23      24      25      26      27
 *   5|  28    29      2A      2B      2C      2D      2E      2F
 *   6|  30    31      32      33      34      35      36      37
 *   7|  38    39      3A      3B      3C      3D      3E      3F
 *   8|  40    41      42      43      44      45      46      47
 *   9|  48    49      4A      4B      4C      4D      4E      4F
 *   A|  50    51      52      53      54      55      56      57
 *   B|  58    59      5A      5B      5C      5D      5E      5F
 *   C|  60    61      62      63      64      65      66      67
 *   D|  68    69      6A      6B      6C      6D      6E      6F
 *
 *  M0110                                                          M0120
 *  ,---------------------------------------------------------.    ,---------------.
 *  |  `|  1|  2|  3|  4|  5|  6|  7|  8|  9|  0|  -|  =|Backs|    |Clr|  -|Lft|Rgt|
 *  |---------------------------------------------------------|    |---------------|
 *  |Tab  |  Q|  W|  E|  R|  T|  Y|  U|  I|  O|  P|  [|  ]|  \|    |  7|  8|  9|Up |
 *  |---------------------------------------------------------|    |---------------|
 *  |CapsLo|  A|  S|  D|  F|  G|  H|  J|  K|  L|  ;|  '|Return|    |  4|  5|  6|Dn |
 *  |---------------------------------------------------------|    |---------------|
 *  |Shift   |  Z|  X|  C|  V|  B|  N|  M|  ,|  ,|  /|        |    |  1|  2|  3|   |
 *  `---------------------------------------------------------'    |-----------|Ent|
 *       |Opt|Mac |         Space               |Enter|Opt|        |      0|  .|   |
 *       `------------------------------------------------'        `---------------'
 *  ,---------------------------------------------------------.    ,---------------.
 *  | 32| 12| 13| 14| 15| 17| 16| 1A| 1C| 19| 1D| 1B| 18|   33|    | 47| 4E| 46| 42|
 *  |---------------------------------------------------------|    |---------------|
 *  |   30| 0C| 0D| 0E| 0F| 10| 11| 20| 22| 1F| 23| 21| 1E| 2A|    | 59| 5B| 5C| 4D|
 *  |---------------------------------------------------------|    |---------------|
 *  |    39| 00| 01| 02| 03| 05| 04| 26| 28| 25| 29| 27|    24|    | 56| 57| 58| 48|
 *  |---------------------------------------------------------|    |---------------|
 *  |      38| 06| 07| 08| 09| 0B| 2D| 2E| 2B| 2F| 2C|      38|    | 53| 54| 55|   |
 *  `---------------------------------------------------------'    |-----------| 4C|
 *       | 3A|  37|             31              |   34| 3A|        |     52| 41|   |
 *       `------------------------------------------------'        `---------------'
 *
 *  M0110A
 *  ,---------------------------------------------------------. ,---------------.
 *  |  `|  1|  2|  3|  4|  5|  6|  7|  8|  9|  0|  -|  =|Bcksp| |Clr|  =|  /|  *|
 *  |---------------------------------------------------------| |---------------|
 *  |Tab  |  Q|  W|  E|  R|  T|  Y|  U|  I|  O|  P|  [|  ]|   | |  7|  8|  9|  -|
 *  |-----------------------------------------------------'   | |---------------|
 *  |CapsLo|  A|  S|  D|  F|  G|  H|  J|  K|  L|  ;|  '|Return| |  4|  5|  6|  +|
 *  |---------------------------------------------------------| |---------------|
 *  |Shift   |  Z|  X|  C|  V|  B|  N|  M|  ,|  ,|  /|Shft|Up | |  1|  2|  3|   |
 *  |---------------------------------------------------------' |-----------|Ent|
 *  |Optio|Mac    |           Space           |  \|Lft|Rgt|Dn | |      0|  .|   |
 *  `---------------------------------------------------------' `---------------'
 *  ,---------------------------------------------------------. ,---------------.
 *  | 32| 12| 13| 14| 15| 17| 16| 1A| 1C| 19| 1D| 1B| 18|   33| | 47| 68| 6D| 62|
 *  |---------------------------------------------------------| |---------------|
 *  |   30| 0C| 0D| 0E| 0F| 10| 11| 20| 22| 1F| 23| 21| 1E|   | | 59| 5B| 5C| 4E|
 *  |-----------------------------------------------------'   | |---------------|
 *  |    39| 00| 01| 02| 03| 05| 04| 26| 28| 25| 29| 27|    24| | 56| 57| 58| 66|
 *  |---------------------------------------------------------| |---------------|
 *  |      38| 06| 07| 08| 09| 0B| 2D| 2E| 2B| 2F| 2C|  38| 4D| | 53| 54| 55|   |
 *  |---------------------------------------------------------' |-----------| 4C|
 *  |   3A|     37|            31             | 2A| 46| 42| 48| |     52| 41|   |
 *  `---------------------------------------------------------' `---------------'
 */
/* returns a no_action keymap */
function no_map()
{
    return [
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
        [0,0,0,0,0,0,0,0],
    ];
}

/* returns a transparent keymap */
function transparent_map()
{
    return [
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
        [1,1,1,1,1,1,1,1],
    ]; 
}

/* default keymaps(8 layers) */
keymaps = [
    [
        [0x04,0x16,0x07,0x09,0x0B,0x0A,0x1D,0x1B,],
        [0x06,0x19,0x00,0x05,0x14,0x1A,0x08,0x15,],
        [0x1C,0x17,0x1E,0x1F,0x20,0x21,0x23,0x22,],
        [0x2E,0x26,0x24,0x2D,0x25,0x27,0x30,0x12,],
        [0x18,0x2F,0x0C,0x13,0x28,0x0F,0x0D,0x34,],
        [0x0E,0x33,0xCD,0x36,0x38,0x11,0x10,0x37,],
        [0x2B,0x2C,0x35,0x2A,0xC0,0x00,0x00,0xE3,],
        [0xE1,0xE0,0xE2,0x00,0x00,0x00,0x00,0x00,],
        [0x00,0x63,0x4F,0x00,0x00,0x00,0x50,0x53,],
        [0x51,0x00,0x00,0x00,0x58,0x52,0x56,0x00,],
        [0x00,0x00,0x62,0x59,0x5A,0x5B,0x5C,0x5D,],
        [0x5E,0x5F,0x00,0x60,0x61,0x00,0x00,0x00,],
        [0x00,0x00,0x55,0x00,0x00,0x00,0x57,0x00,],
        [0x2E,0x00,0x00,0x00,0x00,0x54,0x00,0x00,],
    ],
    [
        [0x50,0x51,0x4F,0x00,0x00,0x00,0x4D,0x00,],
        [0x4E,0x00,0x00,0x00,0x4A,0x52,0x4B,0x00,],
        [0x00,0x00,0x3A,0x3B,0x3C,0x3D,0x3F,0x3E,],
        [0x45,0x42,0x40,0x44,0x41,0x43,0x49,0x47,],
        [0x00,0x52,0x46,0x48,0x28,0x4B,0x00,0x4F,],
        [0x4A,0x50,0xCD,0x4D,0x51,0x00,0x00,0x4E,],
        [0x39,0x2C,0x29,0x4C,0xC0,0x00,0x00,0xE3,],
        [0xE1,0xE0,0xE2,0x00,0x00,0x00,0x00,0x00,],
        [0x00,0x63,0x4D,0x00,0x00,0x00,0x4A,0x53,],
        [0x4E,0x00,0x00,0x00,0x58,0x4B,0x56,0x00,],
        [0x00,0x00,0x62,0x59,0x5A,0x5B,0x5C,0x5D,],
        [0x5E,0x5F,0x00,0x60,0x61,0x00,0x00,0x00,],
        [0x00,0x00,0x55,0x00,0x00,0x00,0x57,0x00,],
        [0x2E,0x00,0x00,0x00,0x00,0x54,0x00,0x00,],
    ],
    no_map(),
    no_map(),
    no_map(),
    no_map(),
    no_map(),
    no_map(),
];

/* Fn actions(32*2) */
fn_actions = [
    0xF1,0xA1,0xF1,0xA2,0xF1,0xA3,0xF1,0xA4,
    0xF1,0xA5,0xF1,0xA6,0xF1,0xA7,0x02,0x8A,
    0x04,0x8A,0x08,0x8A,0xF0,0xA1,0xF0,0xA2,
    0xF0,0xA3,0x31,0xA1,0x2B,0xA2,0x28,0xA3,
    0x2C,0xA4,0x33,0xA5,0x34,0xA6,0x38,0xA7,
    0x2C,0x22,0x2C,0x21,0x34,0x31,0x28,0x31,
    0x29,0x21,0x2A,0x21,0x00,0x21,0x29,0x22,
    0x2A,0x22,0x00,0x22,0x35,0x32,0x31,0x34,
];

/* Fn actions source */
fn_actions_source = "\
    [0]  = ACTION_LAYER_MOMENTARY(1),\n\
    [1]  = ACTION_LAYER_MOMENTARY(2),\n\
    [2]  = ACTION_LAYER_MOMENTARY(3),\n\
    [3]  = ACTION_LAYER_MOMENTARY(4),\n\
    [4]  = ACTION_LAYER_MOMENTARY(5),\n\
    [5]  = ACTION_LAYER_MOMENTARY(6),\n\
    [6]  = ACTION_LAYER_MOMENTARY(7),\n\
    [7]  = ACTION_LAYER_TOGGLE(1),\n\
    [8]  = ACTION_LAYER_TOGGLE(2),\n\
    [9]  = ACTION_LAYER_TOGGLE(3),\n\
    [10] = ACTION_LAYER_TAP_TOGGLE(1),\n\
    [11] = ACTION_LAYER_TAP_TOGGLE(2),\n\
    [12] = ACTION_LAYER_TAP_TOGGLE(3),\n\
    [13] = ACTION_LAYER_TAP_KEY(1, KC_BSLASH),\n\
    [14] = ACTION_LAYER_TAP_KEY(2, KC_TAB),\n\
    [15] = ACTION_LAYER_TAP_KEY(3, KC_ENTER),\n\
    [16] = ACTION_LAYER_TAP_KEY(4, KC_SPACE),\n\
    [17] = ACTION_LAYER_TAP_KEY(5, KC_SCOLON),\n\
    [18] = ACTION_LAYER_TAP_KEY(6, KC_QUOTE),\n\
    [19] = ACTION_LAYER_TAP_KEY(7, KC_SLASH),\n\
    [20] = ACTION_MODS_TAP_KEY(MOD_LSFT, KC_SPACE),\n\
    [21] = ACTION_MODS_TAP_KEY(MOD_LCTL, KC_SPACE),\n\
    [22] = ACTION_MODS_TAP_KEY(MOD_RCTL, KC_QUOTE),\n\
    [23] = ACTION_MODS_TAP_KEY(MOD_RCTL, KC_ENTER),\n\
    [24] = ACTION_MODS_TAP_KEY(MOD_LCTL, KC_ESC),\n\
    [25] = ACTION_MODS_TAP_KEY(MOD_LCTL, KC_BSPACE),\n\
    [26] = ACTION_MODS_ONESHOT(MOD_LCTL),\n\
    [27] = ACTION_MODS_TAP_KEY(MOD_LSFT, KC_ESC),\n\
    [28] = ACTION_MODS_TAP_KEY(MOD_LSFT, KC_BSPACE),\n\
    [29] = ACTION_MODS_ONESHOT(MOD_LSFT),\n\
    [30] = ACTION_MODS_TAP_KEY(MOD_RSFT, KC_GRAVE),\n\
    [31] = ACTION_MODS_TAP_KEY(MOD_RALT, KC_BSLASH),\n\
";

/* Override Fn key setting */
keycodes[223] = {id: 'FN31',                        name: 'LAlt (\\)',                    desc: 'Left Alt with Backslash(Tap key)'};


/* hex file whthout keymap region and eof */
function firmware_hex()
{
    /* HHKB firmware: v4.0-162-g52a7398 */
    /*  Flash Map of ATMega32U4(32KB)
     *  +------------+ 0x0000
     *  | .vectors   | 0xac (43vectors * 4bytes)
     *  | .progmem   | PROGMEM variables and PSTR
     *  | .init0-9   |
     *  | .text      | code
     *  | .fini9-0   |
     *  |            | > text region
     *  |------------| _etext
     *  | .data      |
     *  | .bss       |
     *  | .noinit    |
     *  |            | > data region
     *  |------------| 0x6800
     *  | .keymap    | > keymap region(2KB)
     *  |------------| 0x7000
     *  | bootloader | 4KB
     *  +------------+ 0x7FFF
     */
    // TODO: read hex file directly from remote URL
    return "\
:100000000C94C2040C9406050C9406050C94060589\r\n\
:100010000C9406050C9406050C9406050C94060534\r\n\
:100020000C9406050C9406050C947C0D0C944E0E55\r\n\
:100030000C94BE1C0C9406050C9406050C94060545\r\n\
:100040000C9406050C9406050C9406050C94060504\r\n\
:100050000C9406050C94251D0C9406050C940605BD\r\n\
:100060000C9406050C9406050C9406050C940605E4\r\n\
:100070000C9406050C9406050C9406050C940605D4\r\n\
:100080000C9406050C9406050C9406050C940605C4\r\n\
:100090000C9406050C9406050C9406050C940605B4\r\n\
:1000A0000C9406050C9406050C940605B30ED50EAB\r\n\
:1000B000C00FD50EC00F170F3A0FC00F8F0FA20F32\r\n\
:1000C000D112D112FF12FF12541390138115811512\r\n\
:1000D000A81381159F149F145B15811581156F1549\r\n\
:1000E0000A0025303862003A200025303258000AD4\r\n\
:1000F000722F632030313233343536370A005D0ACF\r\n\
:100100000025303258005B0020002530325800288E\r\n\
:1001100031290A002832290A002833290A00283404\r\n\
:10012000290A000A0025303258006D303131305F25\r\n\
:1001300072656376206572723A20000A00253032BB\r\n\
:1001400058006D303131305F73656E6420657272B6\r\n\
:100150003A20005B735D004B6579626F61726420C9\r\n\
:1001600073746172742E0A0055534220636F6E6679\r\n\
:100170006967757265642E0A005B575D005B535DAD\r\n\
:10018000005B525D005B445D005B435D0032034DEC\r\n\
:1001900000300031003100300020006B0065007934\r\n\
:1001A0000062006F00610072006400200063006F55\r\n\
:1001B000006E007600650072007400650072000039\r\n\
:1001C000000E0374002E006D002E006B002E000048\r\n\
:1001D000000403090409027400040100A0320904A8\r\n\
:1001E00000000103010100092111010001223F006B\r\n\
:1001F0000705810308000A09040100010301020048\r\n\
:10020000092111010001224D000705820308000A9F\r\n\
:10021000090402000103000000092111010001226C\r\n\
:1002200036000705830308000A09040300020300DF\r\n\
:10023000000009211101000122200007058403208C\r\n\
:100240000001070504032000011201100100000055\r\n\
:1002500008EDFE10010101010200010631FF0974E1\r\n\
:10026000A1010975150025FF952075088102097601\r\n\
:10027000150025FF952075089102C005010980A190\r\n\
:1002800001850216010026B7001A01002AB7007581\r\n\
:100290001095018100C0050C0901A101850316011B\r\n\
:1002A00000269C021A01002A9C027510950181000B\r\n\
:1002B000C005010902A1010901A1000509190129CF\r\n\
:1002C00005150025019505750181029501750381CC\r\n\
:1002D000010501093009311581257F9502750881D5\r\n\
:1002E0000609381581257F950175088106050C0AD8\r\n\
:1002F00038021581257F950175088106C0C005016A\r\n\
:100300000906A101050719E029E71500250195084F\r\n\
:1003100075018102950175088101050819012905FA\r\n\
:100320009505750191029501750391010507190065\r\n\
:1003300029FF150025FF950675088100C00A0025D4\r\n\
:1003400030325820006B6579626F6172645F72654C\r\n\
:10035000706F72743A20000A0025303258006B65C5\r\n\
:1003600079626F6172645F7365745F6C65643A2073\r\n\
:1003700000290A002575002F002575005D2800253D\r\n\
:10038000640020002564002000256400200025640E\r\n\
:10039000007C0025303258006D6F7573656B657990\r\n\
:1003A000205B62746E7C782079207620685D2872EC\r\n\
:1003B00065702F61636C293A205B006D6B5F776815\r\n\
:1003C00065656C5F74696D655F746F5F6D617820E2\r\n\
:1003D0003D2025640A006D6B5F776865656C5F6D15\r\n\
:1003E00061785F7370656564203D2025640A006D47\r\n\
:1003F0006B5F74696D655F746F5F6D6178203D2020\r\n\
:1004000025640A006D6B5F6D61785F73706565646C\r\n\
:10041000203D2025640A006D6B5F696E74657276FD\r\n\
:10042000616C203D2025640A006D6B5F64656C6122\r\n\
:1004300079203D2025640A006D6B5F776865656CE7\r\n\
:100440005F74696D655F746F5F6D6178203D202515\r\n\
:10045000640A006D6B5F776865656C5F6D61785FDE\r\n\
:100460007370656564203D2025640A006D6B5F74C0\r\n\
:10047000696D655F746F5F6D6178203D2025640A4A\r\n\
:10048000006D6B5F6D61785F7370656564203D2002\r\n\
:1004900025640A006D6B5F696E74657276616C200D\r\n\
:1004A0003D2025640A006D6B5F64656C6179203DB9\r\n\
:1004B0002025640A000A00257500363A2077686511\r\n\
:1004C000656C5F74696D655F746F5F6D61783A200C\r\n\
:1004D000000A00257500353A20776865656C5F6D08\r\n\
:1004E00061785F73706565643A20000A00257500C5\r\n\
:1004F000343A2074696D655F746F5F6D61783A207E\r\n\
:10050000000A00257500333A206D61785F737065CD\r\n\
:1005100065643A20000A00257500323A20696E743D\r\n\
:10052000657276616C286D73293A20000A00257582\r\n\
:1005300000313A2064656C6179282A31306D732965\r\n\
:100540003A20000A092D2056616C756573202D0A2A\r\n\
:10055000004D3E004D25643E20003F007365742031\r\n\
:1005600064656661756C740A00433E2000776865B7\r\n\
:1005700072652064656C74613A20637572736F7282\r\n\
:100580003D25642C20776865656C3D25640A5365BC\r\n\
:100590006520687474703A2F2F656E2E77696B69C9\r\n\
:1005A00070656469612E6F72672F77696B692F4D73\r\n\
:1005B0006F7573655F6B6579730A000A092D204DAD\r\n\
:1005C0006F7573656B6579202D0A4553432F713A1A\r\n\
:1005D00009717569740A313A0964656C6179282A70\r\n\
:1005E00031306D73290A323A09696E746572766129\r\n\
:1005F0006C286D73290A333A096D61785F737065F1\r\n\
:1006000065640A343A0974696D655F746F5F6D6182\r\n\
:10061000780A353A09776865656C5F6D61785F7354\r\n\
:10062000706565640A363A09776865656C5F746958\r\n\
:100630006D655F746F5F6D61780A0A703A09707258\r\n\
:10064000696E742076616C7565730A643A09736526\r\n\
:10065000742064656661756C74730A75703A092B51\r\n\
:10066000310A646F776E3A092D310A706775703AF6\r\n\
:10067000092B31300A7067646F776E3A092D31307B\r\n\
:100680000A0A7370656564203D2064656C7461209E\r\n\
:100690002A206D61785F7370656564202A20287256\r\n\
:1006A0006570656174202F2074696D655F746F5F7C\r\n\
:1006B0006D6178290A003F004D3E2000433E200036\r\n\
:1006C0004C25640A000A092D20436F6E736F6C6518\r\n\
:1006D000202D0A4553432F713A09717569740A6DCB\r\n\
:1006E0003A096D6F7573656B65790A000A092D20EB\r\n\
:1006F0004D61676963202D0A643A09646562756714\r\n\
:100700000A783A096465627567206D617472697868\r\n\
:100710000A6B3A096465627567206B6579626F617F\r\n\
:1007200072640A6D3A096465627567206D6F75734E\r\n\
:10073000650A763A0976657273696F6E0A733A09CB\r\n\
:100740007374617475730A633A09636F6E736F6CC7\r\n\
:1007500065206D6F64650A302D343A096C617965E6\r\n\
:1007600072302D34284631302D4634290A506175B7\r\n\
:10077000733A09626F6F746C6F616465720A003F4F\r\n\
:100780000074696D65725F636F756E743A20253011\r\n\
:10079000346C580A006B6579626F6172645F6964DA\r\n\
:1007A0006C653A2025580A006B6579626F61726446\r\n\
:1007B0005F70726F746F636F6C3A2025580A00681F\r\n\
:1007C0006F73745F6B6579626F6172645F6C65648F\r\n\
:1007D0007328293A2025580A000A092D20537461EC\r\n\
:1007E000747573202D0A004743433A20342E382E67\r\n\
:1007F00031204156522D4C4942433A20312E382E59\r\n\
:100800003073766E204156525F415243483A206120\r\n\
:100810007672350A004F5054494F4E533A204C558A\r\n\
:100820004641204D4F5553454B455920455854524C\r\n\
:10083000414B455920434F4E534F4C4520434F4D5C\r\n\
:100840004D414E44204B45594D41505F5345435413\r\n\
:10085000494F4E20343039360A004255494C443A0B\r\n\
:1008600020353037656262332D64697274792028CF\r\n\
:1008700031363A31383A3339204A756C20313120DB\r\n\
:1008800032303135290A005649443A2030784645FD\r\n\
:10089000454428742E6D2E6B2E29205049443A2051\r\n\
:1008A000307830313130284D30313130206B65793E\r\n\
:1008B000626F61726420636F6E766572746572290F\r\n\
:1008C000205645523A203078303130310A004445C4\r\n\
:1008D00053433A20636F6E76657274204D30313128\r\n\
:1008E00030206B6579626F61726420746F2055539C\r\n\
:1008F000420A000A092D2056657273696F6E202D19\r\n\
:100900000A000A6D6F7573653A206F66660A000A01\r\n\
:100910006D6F7573653A206F6E0A000A6B657962B8\r\n\
:100920006F6172643A206F66660A000A6B657962CD\r\n\
:100930006F6172643A206F6E0A000A6D61747269A9\r\n\
:10094000783A206F66660A000A6D61747269783AB7\r\n\
:10095000206F6E0A000A64656275673A206F6666EA\r\n\
:100960000A000A64656275673A206F6E0A000A0A17\r\n\
:10097000626F6F746C6F616465722E2E2E2000435F\r\n\
:100980003E20000011241FBECFEFDAE0DEBFCDBF56\r\n\
:1009900004B603FE24C08091D4019091D501A091AA\r\n\
:1009A000D601B091D7018730904BA740B04BB9F436\r\n\
:1009B0001092D4011092D5011092D6011092D70155\r\n\
:1009C00014BE84B7877F84BF88E10FB6F894809304\r\n\
:1009D0006000109260000FBEE0E0F8E3099511E0BE\r\n\
:1009E000A0E0B1E0E6E8FAE402C005900D92A2337F\r\n\
:1009F000B107D9F721E0A2E3B1E001C01D92A43D07\r\n\
:100A0000B207E1F70E94B20A0C9441250C94000051\r\n\
:100A1000FF93EF93E0913201F0913301309709F0A9\r\n\
:100A20000995EF91FF910895FC018591803011F0B7\r\n\
:100A3000EFDFFBCF0895FF27E0E230E247FF0CC075\r\n\
:100A4000419597FF09C0EDE260957095809590956E\r\n\
:100A5000611D711D811D911D27FF02C0219530E38D\r\n\
:100A600050E2AA27660F771F881F991FAA1FA41795\r\n\
:100A700010F0A41B63955A95A9F7AA3008F0A95F56\r\n\
:100A8000A05DAF93F395611571058105910541F75F\r\n\
:100A9000ED3211F4EF93F395F21718F43F93F395B9\r\n\
:100AA000FBCF8F91B5DFFA95E1F70895E991F991C0\r\n\
:100AB0008591803021F0853219F0AADFF9CF0895B1\r\n\
:100AC00020E0E89455915532C1F3503311F4689405\r\n\
:100AD00055915A3348F4505390F3220F022E220FAF\r\n\
:100AE000220F200D250FF4CF0EF4219589919991B5\r\n\
:100AF000533619F3533729F1533559F1BC0188277F\r\n\
:100B00009927E8945C3621F48991999168945591DC\r\n\
:100B1000543639F446EF7EF077FF0DC08FEF9FEF2C\r\n\
:100B20000AC055374AE039F0583540E121F05236D5\r\n\
:100B300042E009F00895FF93EF937DDFEF91FF917D\r\n\
:100B4000B7CFFF93EF93FC0181918030B9F360DF61\r\n\
:100B5000FBCFFF93EF9368DFF1CFDF93CF93CDB758\r\n\
:100B6000DEB72596A3DFCF91DF9108950E94B806E6\r\n\
:100B7000E4E3F1E0119281E0E234F807D9F784E38D\r\n\
:100B800091E090934301809342010895CF93109296\r\n\
:100B900044010E94D407C82F8B3709F443C08F3F0C\r\n\
:100BA00009F440C081E0809344019C2F969596956E\r\n\
:100BB0009695E0914201F09143018C2F8770C7FF19\r\n\
:100BC0000DC09F70E90FF11D21E030E001C0220F40\r\n\
:100BD0008A95EAF72095808182230AC0E90FF11DEA\r\n\
:100BE00021E030E001C0220F8A95EAF78081822B54\r\n\
:100BF00080838091B60180FF17C086E091E00E945B\r\n\
:100C000014051F92CF9381E091E09F938F930E94F0\r\n\
:100C1000AD058EEF90E00E9414050F900F900F909D\r\n\
:100C20000F9002C080E001C081E0CF910895E09173\r\n\
:100C30004201F0914301E80FF11D80810895EF9288\r\n\
:100C4000FF920F931F93CF93DF938FEE90E00E945C\r\n\
:100C50001405C0E0D0E08AEEE82E80E0F82E02EE27\r\n\
:100C600010E0DF93CF93FF92EF920E94AD0587EEE5\r\n\
:100C700090E00E941405E0914201F0914301EC0FD5\r\n\
:100C8000FD1F80810E946D1C1F928F931F930F93F5\r\n\
:100C90000E94AD0580EE90E00E94140521968DB76C\r\n\
:100CA0009EB708960FB6F8949EBF0FBE8DBFCE308C\r\n\
:100CB000D105B9F6DF91CF911F910F91FF90EF9081\r\n\
:100CC0000895569A81FF02C05E9A08955E9808952D\r\n\
:100CD000E72FF0E09EE0899FE00DF11D112483E0F5\r\n\
:100CE000EE0FFF1F8A95E1F7E60FF11DE05CF74973\r\n\
:100CF00084910895E82FF0E0EE0FFF1FE058F949C6\r\n\
:100D00008591949108955198599A08955898509AB8\r\n\
:100D100008955098589A08955198599A85E08A955F\r\n\
:100D2000F1F7000089B1869581700895CF93DF9324\r\n\
:100D3000EC010E948C06882341F0209731F085E079\r\n\
:100D40008A95F1F700002197F4CFCE01DF91CF9182\r\n\
:100D500008958B3759F08F3F31F0982F9F779695F4\r\n\
:100D60008078982B01C09FEF892F08958BE7089515\r\n\
:100D70000E9483060E9489062FEF83ED90E32150A5\r\n\
:100D800080409040E1F700C000000895EF92FF928C\r\n\
:100D90000F931F93CF93DF93E82E109248010E9488\r\n\
:100DA00083060E948606CAEFD0E088EE93E00E9498\r\n\
:100DB0009606892B29F421972097B9F781E038C04E\r\n\
:100DC00008E010E080E8F82E8AEF90E00E94960696\r\n\
:100DD000892B11F483E02CC08F2D8E2129F00E94E5\r\n\
:100DE0008906C8ECD0E00AC00E948606FACF209798\r\n\
:100DF00059F025E02A95F1F7000021970E948C0612\r\n\
:100E00008823A9F3CD2B11F484E012C0F69401508D\r\n\
:100E1000110901151105C1F68FE891E00197F1F76D\r\n\
:100E200000C000000E9483060E94890681E026C05F\r\n\
:100E30008093480182E491E00E941405809148016A\r\n\
:100E40001F928F938DE391E09F938F930E94AD0546\r\n\
:100E50008BE391E00E9414059FEF29E688E1915011\r\n\
:100E600020408040E1F700C000000E9483060E94FD\r\n\
:100E700089060F900F900F900F9080E0DF91CF9137\r\n\
:100E80001F910F91FF90EF9008950F931F93CF93B1\r\n\
:100E9000DF9310924801CAEFD0E088EE93E00E9401\r\n\
:100EA0009606892B29F421972097B9F781E02DC068\r\n\
:100EB00008E010E0110F88EC90E00E949606892B64\r\n\
:100EC00019F0C8ECD0E009C082E01FC0209759F0AB\r\n\
:100ED00025E02A95F1F7000021970E948C068823CF\r\n\
:100EE000A9F3CD2B11F483E010C05098589A85E0F7\r\n\
:100EF0008A95F1F70000489911600150D9F60E94D7\r\n\
:100F000083060E948906812F26C0809348018AE2C9\r\n\
:100F100091E00E941405809148011F928F9385E211\r\n\
:100F200091E09F938F930E94AD0583E291E00E9430\r\n\
:100F300014059FEF29E688E1915020408040E1F7B9\r\n\
:100F400000C000000E9483060E9489060F900F9047\r\n\
:100F50000F900F908FEFDF91CF911F910F91089518\r\n\
:100F6000CF9384E10E94C6060E944507C82F8B37A5\r\n\
:100F7000C1F08091B60180FF0CC01F92CF932AE090\r\n\
:100F800031E03F932F930E94AD050F900F900F908B\r\n\
:100F90000F908091B60180FF04C088E091E00E942C\r\n\
:100FA00014058C2FCF910895CF93DF938091470143\r\n\
:100FB000882319F0109247017EC080914601882352\r\n\
:100FC00019F01092460177C0C0914501CC2319F069\r\n\
:100FD0001092450103C00E94B007C82F8C2F8F7755\r\n\
:100FE0008137B1F0893709F061C00E94B007982FAE\r\n\
:100FF0009F779D3041F018F4953039F404C0913159\r\n\
:1010000011F09B3111F487FD37C00E94A9063AC048\r\n\
:101010000E94B007982F9F77913719F0993721F0E8\r\n\
:1010200041C08093450142C00E94B007D82F8F77FE\r\n\
:101030008D3041F018F4853081F504C0813111F014\r\n\
:101040008B3159F5C7FF11C0D7FF0AC08EE191E07F\r\n\
:101050000E9414058C2F0E94A906809346010BC0A4\r\n\
:1010600089E191E00E94140521C0D7FF0DC084E101\r\n\
:1010700091E00E9414058D2F0E94A906982F90667A\r\n\
:1010800090934701806417C08FE091E00E9414059F\r\n\
:101090008D2F0E94A90680660EC08D2F0E94A90682\r\n\
:1010A000806402C00E94A906809347018C2FDF91C3\r\n\
:1010B000CF910C94A906DF91CF91089580915401AE\r\n\
:1010C00008959FB7F89410924B019FBF9091CB0168\r\n\
:1010D000943009F058C09091E9009F702091EC0085\r\n\
:1010E00020FF02C020E801C020E0292B94E090936B\r\n\
:1010F000E9009091EB0090FF43C09091EE0097FFC4\r\n\
:101100003FC090914901992321F09091E80095FF0B\r\n\
:1011100037C01092490196E03091E80035FD15C0C6\r\n\
:101120003091CB01343061F53091EB0035FD28C0B2\r\n\
:10113000915021F481E08093490122C0EFE9FFE062\r\n\
:101140003197F1F700C00000E7CF8093F100809164\r\n\
:10115000E80085FD0AC08091E80080FFFCCF809107\r\n\
:10116000E8008E778093E80006C08FB7F89491E08E\r\n\
:1011700090934B018FBF2F702093E90080E008957A\r\n\
:101180002F702093E9008FEF0895CF93DF9300D065\r\n\
:101190001F92CDB7DEB72091CB01243019F523E0A3\r\n\
:1011A00029839B838A832093E9008FEF9091E80045\r\n\
:1011B000815095FD06C095ED9A95F1F700008111DB\r\n\
:1011C000F5CF8091E80085FF0DC040E050E063E07E\r\n\
:1011D00070E0CE0101960E946F0B8091E8008E773F\r\n\
:1011E0008093E8000F900F900F90DF91CF910895BA\r\n\
:1011F000CF93DF9300D01F92CDB7DEB72091CB0104\r\n\
:10120000243021F522E029839B838A8383E0809325\r\n\
:10121000E9008FEF9091E800815095FD06C095EDB3\r\n\
:101220009A95F1F700008111F5CF8091E80085FFD4\r\n\
:101230000DC040E050E063E070E0CE0101960E94F6\r\n\
:101240006F0B8091E8008E778093E8000F900F90ED\r\n\
:101250000F90DF91CF9108952091CB012430F1F4CC\r\n\
:1012600022E02093E9002FEF3091E800215035FD76\r\n\
:1012700006C035ED3A95F1F700002111F5CF209128\r\n\
:10128000E80025FF0BC040E050E065E070E00E9400\r\n\
:101290006F0B8091E8008E778093E8000895CF93DC\r\n\
:1012A000DF93EC018091CB01843039F581E08093AC\r\n\
:1012B000E9008FEF9091E800815095FD06C095ED13\r\n\
:1012C0009A95F1F700008111F5CF8091E80085FF34\r\n\
:1012D00014C040E050E068E070E0CE010E946F0B67\r\n\
:1012E0008091E8008E778093E80088E0FE01ACE40E\r\n\
:1012F000B1E001900D928A95E1F7DF91CF910895C9\r\n\
:1013000089E891E00E9414058091CA01811109C009\r\n\
:101310000E94010D0E945E0D8091E2008460809326\r\n\
:10132000E200089585E891E00E9414051092CA0138\r\n\
:10133000089581E891E00C9414058DE791E00E94F6\r\n\
:1013400014050C94A61C89E791E00E9414050C94E6\r\n\
:10135000BC1C80914A018F5F80934A0162E30E9426\r\n\
:101360000725911135C010924A0180914B018823C5\r\n\
:1013700079F18091CB01843049F58091E9008F703B\r\n\
:101380009091EC0090FF02C090E801C090E0982B93\r\n\
:1013900084E08093E9008091EB0080FF14C080918D\r\n\
:1013A000EE0087FF10C08091E80085FF03C0109217\r\n\
:1013B000F100F9CF8091E80080FF05C08091E8003E\r\n\
:1013C0008E778093E8009F709093E90010924B0114\r\n\
:1013D000089542E061EC81E00E947B0C42E061EC08\r\n\
:1013E00082E00E947B0C42E061EC83E00E947B0C77\r\n\
:1013F00046E261EC84E00C947B0C8091CD0183305B\r\n\
:1014000009F453C030F4813071F0823009F491C096\r\n\
:1014100008958A3009F47DC08B3009F45EC08930AC\r\n\
:1014200009F09FC020C08091CC01813A09F099C099\r\n\
:101430008091E800877F8093E8008091D0019091AF\r\n\
:10144000D101892B21F060E080E090E003C068E0EA\r\n\
:101450008CE491E070E00E94B80B8091E8008B77FB\r\n\
:101460008093E80008958091CC01813209F079C021\r\n\
:101470008091D0019091D101892B09F072C08091A7\r\n\
:10148000E800877F8093E8008091E80082FD05C036\r\n\
:101490008091CB018111F8CF64C08091F1008093DD\r\n\
:1014A00054018091E8008B7758C08091CC01813A3B\r\n\
:1014B00009F057C08091D0019091D101892B09F09A\r\n\
:1014C00050C08091E800877F8093E8008091E80019\r\n\
:1014D00080FFFCCF80910A013BC08091CC0181321A\r\n\
:1014E00009F03FC08091D0019091D101892BC9F5BD\r\n\
:1014F0008091E800877F8093E8000E94B00C909173\r\n\
:10150000CE0181E0911101C080E080930A010C942A\r\n\
:10151000A2158091CC01813221F58091E800877F6E\r\n\
:101520008093E8000E94B00C8091CF018093550118\r\n\
:1015300008958091CC01813AA1F48091E800877FE1\r\n\
:101540008093E8008091E80080FFFCCF80915501F6\r\n\
:101550008093F1008091E8008E778093E8000C94EE\r\n\
:10156000B00C089584B7877F84BF88E10FB6F894E4\r\n\
:1015700080936000109260000FBE90E080E80FB68C\r\n\
:10158000F89480936100909361000FBE0E946610F2\r\n\
:101590000E94010D0E945E0D8091E20084608093A4\r\n\
:1015A000E20081E698E00E94681C78948091CB016B\r\n\
:1015B0008430E1F788E691E00E9414050E946810EB\r\n\
:1015C00080E091E00E94D80F87E591E00E94140529\r\n\
:1015D0008091CB01853089F483E591E00E94140568\r\n\
:1015E0000E947F1C8091C901882391F30E94A71C4F\r\n\
:1015F000882371F30E94590BEBCF0E949410E8CF1F\r\n\
:10160000292F332723303105A9F06CF4213031051F\r\n\
:1016100009F442C02230310509F043C084E790E06C\r\n\
:1016200025ED31E042C021323105C9F022323105C9\r\n\
:1016300019F137C099278130910541F08230910529\r\n\
:1016400041F0892B71F5E1EDF1E005C0E1ECF1E04D\r\n\
:1016500002C0EDE8F1E0849190E09F0126C0643083\r\n\
:1016600000F5E62FF0E0EE0FFF1FE15EFE4F208158\r\n\
:10167000318189E090E019C0643098F4E62FF0E001\r\n\
:10168000DF01AA0FBB1FA95EBE4F2D913C91ED5EFD\r\n\
:10169000FE4F808190E009C082E190E029E432E0D1\r\n\
:1016A00004C080E090E020E030E0FA013183208344\r\n\
:1016B000089580E189BD82E189BD09B400FEFDCFB6\r\n\
:1016C0008091D8008F7D8093D8008091E000826067\r\n\
:1016D0008093E0008091E00081FDFCCF0895CF92DF\r\n\
:1016E000DF92EF92FF920F931F93CF93DF937C01D2\r\n\
:1016F0008B01EA010E94D10C811131C0209731F099\r\n\
:1017000088819981081B190BE80EF91EC12CD12C78\r\n\
:101710000115110519F18091E80085FD14C0809133\r\n\
:10172000E8008E778093E800209741F088819981C6\r\n\
:101730008C0D9D1D9983888385E011C00E94D10C7A\r\n\
:10174000882331F30CC0F70181917F018093F10070\r\n\
:1017500001501109FFEFCF1ADF0ADACF80E0DF91E5\r\n\
:10176000CF911F910F91FF90EF90DF90CF90089550\r\n\
:101770002091D2013091D3012617370748F0611527\r\n\
:10178000710539F42091E8002E772093E80001C01C\r\n\
:10179000B901FC0120E061157105B9F18091CB011F\r\n\
:1017A000882309F440C0853009F43FC08091E800E7\r\n\
:1017B00083FD3DC08091E80082FF06C08091E80073\r\n\
:1017C00082FF26C080E008958091E80080FFE3CF8B\r\n\
:1017D0002091F3008091F20090E0922B6115710549\r\n\
:1017E00051F08830910538F421912093F100615037\r\n\
:1017F00071090196F3CF21E0089709F020E080916C\r\n\
:10180000E8008E778093E800C6CF2111C7CFD6CFEE\r\n\
:101810008091CB01882339F0853039F08091E80040\r\n\
:1018200083FFCCCF04C082E0089583E0089581E077\r\n\
:1018300008952091D2013091D3012617370748F03F\r\n\
:101840006115710539F42091E8002E772093E800A6\r\n\
:1018500001C0B901FC0120E061157105C1F1809161\r\n\
:10186000CB01882309F441C0853009F440C0809140\r\n\
:10187000E80083FD3EC08091E80082FF06C08091B1\r\n\
:10188000E80082FF27C080E008958091E80080FF93\r\n\
:10189000E3CF2091F3008091F20090E0922B61154C\r\n\
:1018A000710559F08830910540F424912093F1009E\r\n\
:1018B0003196615071090196F2CF21E0089709F045\r\n\
:1018C00020E08091E8008E778093E800C5CF211159\r\n\
:1018D000C6CFD5CF8091CB01882339F0853039F040\r\n\
:1018E0008091E80083FFCBCF04C082E0089583E0BD\r\n\
:1018F000089581E00895982F973058F59093E90066\r\n\
:10190000981739F07091EC002091ED005091F000A3\r\n\
:1019100003C0242F762F50E021FF19C03091EB0037\r\n\
:101920003E7F3093EB003091ED003D7F3093ED0032\r\n\
:101930003091EB0031603093EB007093EC0020931A\r\n\
:10194000ED005093F0002091EE0027FF07C09F5F4D\r\n\
:10195000D3CF8F708093E90081E0089580E00895EF\r\n\
:101960008091CC0187FD05C08091E80080FF0EC00A\r\n\
:1019700012C08091E80082FD05C08091CB018111E9\r\n\
:10198000F8CF08958091E8008B7708C08091CB0153\r\n\
:101990008111EACF08958091E8008E778093E80066\r\n\
:1019A00008958091E4009091E50045E62091EC00D7\r\n\
:1019B00020FF21C02091E80020FD21C02091CB0113\r\n\
:1019C000222389F0253089F02091EB0025FD0FC0FE\r\n\
:1019D0002091E4003091E5002817390739F3415090\r\n\
:1019E00041F0C901E3CF82E0089583E0089581E0EA\r\n\
:1019F000089584E008952091E80022FFDFCF80E081\r\n\
:101A000008950E946F0D0E94770DE0EEF0E0808156\r\n\
:101A100081608083E8EDF0E080818F77808319BC5E\r\n\
:101A2000A7EDB0E08C918E7F8C9380818F7E808338\r\n\
:101A30001092CA0108950F931F93CF93DF930E94D2\r\n\
:101A40006F0D0E94770DC8EDD0E088818F77888375\r\n\
:101A500088818068888388818F7D888319BC1092F3\r\n\
:101A6000CB011092C7011092C9011092C80100EE7B\r\n\
:101A700010E0F80180818B7F80838881816088837A\r\n\
:101A800042E060E080E00E947B0CE1EEF0E08081CB\r\n\
:101A90008E7F8083E2EEF0E08081816080838081B0\r\n\
:101AA00088608083F80180818E7F80838881806157\r\n\
:101AB0008883DF91CF911F910F910895E8EDF0E0B9\r\n\
:101AC00080818F7E8083E7EDF0E08081816080837C\r\n\
:101AD00084E082BF81E08093CA010C941B0DE8ED85\r\n\
:101AE000F0E080818E7F80831092E2000895109252\r\n\
:101AF000DA001092E10008951F920F920FB60F9234\r\n\
:101B000011242F933F934F935F936F937F938F9302\r\n\
:101B10009F93AF93BF93EF93FF938091E10082FF78\r\n\
:101B20000BC08091E20082FF07C08091E1008B7FB3\r\n\
:101B30008093E1000E94A9098091DA0080FF1FC014\r\n\
:101B40008091D80080FF1BC08091DA008E7F809347\r\n\
:101B5000DA008091D90080FF0DC080E189BD82E16B\r\n\
:101B600089BD09B400FEFDCF81E08093CB010E94C6\r\n\
:101B7000800905C019BC1092CB010E949209809186\r\n\
:101B8000E10080FF19C08091E20080FF15C08091C4\r\n\
:101B9000E2008E7F8093E2008091E200806180937A\r\n\
:101BA000E2008091D80080628093D80019BC85E063\r\n\
:101BB0008093CB010E949D098091E10084FF30C099\r\n\
:101BC0008091E20084FF2CC080E189BD82E189BD63\r\n\
:101BD00009B400FEFDCF8091D8008F7D8093D8009E\r\n\
:101BE0008091E1008F7E8093E1008091E2008F7E02\r\n\
:101BF0008093E2008091E20081608093E200809116\r\n\
:101C0000C701882311F084E007C08091E30087FFBB\r\n\
:101C100002C083E001C081E08093CB010E94A30950\r\n\
:101C20008091E10083FF29C08091E20083FF25C0FD\r\n\
:101C30008091E100877F8093E10082E08093CB0177\r\n\
:101C40001092C7018091E1008E7F8093E100809126\r\n\
:101C5000E2008E7F8093E2008091E20080618093B9\r\n\
:101C6000E20042E060E080E00E947B0C8091F000A6\r\n\
:101C700088608093F0000E949909FF91EF91BF91D5\r\n\
:101C8000AF919F918F917F916F915F914F913F9114\r\n\
:101C90002F910F900FBE0F901F9018951F920F92CB\r\n\
:101CA0000FB60F9211242F933F934F935F936F932F\r\n\
:101CB0007F938F939F93AF93BF93CF93EF93FF93B4\r\n\
:101CC000C091E900CF708091EC001092E900809102\r\n\
:101CD000F000877F8093F00078940E948A0E109223\r\n\
:101CE000E9008091F00088608093F000C093E900E3\r\n\
:101CF000FF91EF91CF91BF91AF919F918F917F9184\r\n\
:101D00006F915F914F913F912F910F900FBE0F9068\r\n\
:101D10001F9018951F93CF93DF93CDB7DEB7AA9787\r\n\
:101D20000FB6F894DEBF0FBECDBFECECF1E08091B2\r\n\
:101D3000F100819321E0E43DF207C9F70E94FD091B\r\n\
:101D40008091E80083FF1CC12091CC013091CD012E\r\n\
:101D5000832F90E08A30910508F012C1FC01EA5A05\r\n\
:101D6000FF4F0C942725203881F0223809F008C154\r\n\
:101D70008091D0018F708093E9008091EB0085FB0A\r\n\
:101D8000882780F91092E90006C08091C8019091DF\r\n\
:101D9000C901911182609091E800977F9093E800CB\r\n\
:101DA0008093F1001092F100C5C0822F8D7F09F061\r\n\
:101DB000E7C0222319F0223061F0E2C08091CE0109\r\n\
:101DC000813009F0DDC0333009F080E08093C90133\r\n\
:101DD00028C08091CE01811124C02091D0012F70A4\r\n\
:101DE00009F4CEC02093E9008091EB0080FF19C078\r\n\
:101DF0008091EB00333011F4806211C080618093D8\r\n\
:101E0000EB0081E090E0022E01C0880F0A94EAF70F\r\n\
:101E10008093EA001092EA008091EB008860809342\r\n\
:101E2000EB001092E9008091E800877F86C02111C5\r\n\
:101E3000A7C01091CE011F778091E3008078812B9D\r\n\
:101E40008093E3008091E800877F8093E8000E9400\r\n\
:101E5000B00C8091E80080FFFCCF8091E3008068A7\r\n\
:101E60008093E300112311F083E001C082E08093AE\r\n\
:101E7000CB0186C02058223008F082C08091CE016C\r\n\
:101E80009091CF018C3D23E0920779F583E08A831E\r\n\
:101E90008AE289834FB7F894DE01139620E03EE092\r\n\
:101EA00051E2E32FF0E050935700E49120FF03C08C\r\n\
:101EB000E295EF703F5FEF708E2F90E0EA3010F008\r\n\
:101EC000C79601C0C0968D939D932F5F243149F72B\r\n\
:101ED0004FBF8091E800877F8093E8006AE270E05E\r\n\
:101EE000CE0101960E94B80B14C0AE014F5F5F4F48\r\n\
:101EF0006091D0010E94000B009709F441C020912D\r\n\
:101F0000E800277F2093E800BC0189819A810E9424\r\n\
:101F1000190C8091E8008B778093E80031C020385D\r\n\
:101F200079F58091E800877F8093E8008091C70170\r\n\
:101F30008093F1008091E8008E778093E8000E9402\r\n\
:101F4000B00C1EC021111CC09091CE019230C0F483\r\n\
:101F50008091E800877F8093E8009093C7010E94FA\r\n\
:101F6000B00C8091C701811104C08091E30087FF0C\r\n\
:101F700002C084E001C081E08093CB010E94E909A6\r\n\
:101F80008091E80083FF0AC08091E800877F8093FA\r\n\
:101F9000E8008091EB0080628093EB00AA960FB678\r\n\
:101FA000F894DEBF0FBECDBFDF91CF911F91089592\r\n\
:101FB00090935B0180935A010895E0915A01F0914A\r\n\
:101FC0005B01309721F00190F081E02D099480E0D1\r\n\
:101FD0000895FF920F931F93CF93DF938C01E091AD\r\n\
:101FE0005A01F0915B01309799F10280F381E02D65\r\n\
:101FF00009958091B60182FF2BC080FF04C085E463\r\n\
:1020000093E00E941405E80188E0F82E0FE313E046\r\n\
:102010008091B60180FF0BC088811F928F931F9320\r\n\
:102020000F930E94AD050F900F900F900F90FA94B0\r\n\
:102030002196F110EDCF8091B60180FF09C08DE3AC\r\n\
:1020400093E0DF91CF911F910F91FF900C941405B5\r\n\
:10205000DF91CF911F910F91FF900895E0915A0168\r\n\
:10206000F0915B01309721F00480F581E02D099417\r\n\
:10207000089520915801309159018217930771F00A\r\n\
:102080009093590180935801E0915A01F0915B01BE\r\n\
:10209000309721F00680F781E02D09940895209172\r\n\
:1020A0005601309157018217930771F090935701B1\r\n\
:1020B00080935601E0915A01F0915B01309721F035\r\n\
:1020C0000084F185E02D0994089508950C9465101D\r\n\
:1020D0000E94E71C0C94B605CF93C82F8091B601DF\r\n\
:1020E00082FF1EC080FF04C08EE593E00E941405AD\r\n\
:1020F0008091B60180FF0CC01F92CF9329E533E099\r\n\
:102100003F932F930E94AD050F900F900F900F906B\r\n\
:102110008091B60180FF04C087E593E00E9414051A\r\n\
:102120008C2FCF910C946106CF92DF92EF92FF92A9\r\n\
:102130000F931F93CF93DF93CDB7DEB72B970FB6D7\r\n\
:10214000F894DEBF0FBECDBF0E94C6053DE5E32E6D\r\n\
:1021500031E0F32E00E010E0C02E802F0E94170621\r\n\
:10216000F701D1907F01D826B1F40F5F1F4F0E30D9\r\n\
:10217000110591F78FEF89838A831B820E94F01CDF\r\n\
:102180008160782F9D838C8349815A816B818D81F9\r\n\
:102190000E94371141C09091B60191FF04C08B8716\r\n\
:1021A0000E941F068B8520E030E04D2D50E0922FDD\r\n\
:1021B000BA01022E02C0759567950A94E2F760FF96\r\n\
:1021C00025C02E83CF82EE24E394F12C02C0EE0CC6\r\n\
:1021D000FF1C9A95E2F790E08E219F2121E0892B48\r\n\
:1021E00009F420E028870E94F01C8160782F9A87EC\r\n\
:1021F00089874E815F8168858A850E943711F80141\r\n\
:10220000E35AFE4F80818E25808306C02F5F3F4FAB\r\n\
:102210002830310561F6A9CF0E94681F10915C013A\r\n\
:102220000E94DD0F1817A1F00E94DD0F80935C0162\r\n\
:102230002B960FB6F894DEBF0FBECDBFDF91CF91C6\r\n\
:102240001F910F91FF90EF90DF90CF900C946C1046\r\n\
:102250002B960FB6F894DEBF0FBECDBFDF91CF91A6\r\n\
:102260001F910F91FF90EF90DF90CF900895CF9343\r\n\
:10227000DF93CDB7DEB72B970FB6F894DEBF0FBE56\r\n\
:10228000CDBF4F83588769877A878B87DE01119688\r\n\
:1022900086E0FD0111928A95E9F785E0FE01379607\r\n\
:1022A00001900D928A95E1F749815A816B817C8179\r\n\
:1022B0008D819E810E946E182B960FB6F894DEBF1A\r\n\
:1022C0000FBECDBFDF91CF910895CF93C82F882344\r\n\
:1022D00009F4C1C0823859F40E94DD0F81FDBBC0F2\r\n\
:1022E00089E30E94091B0E94841B89E30CC0833888\r\n\
:1022F00079F40E94DD0F80FDAEC083E50E94091BCA\r\n\
:102300000E94841B83E50E942A1BCF910C94841B9E\r\n\
:10231000843859F40E94DD0F82FD9DC087E40E943D\r\n\
:10232000091B0E94841B87E4EECF8CEF8C0F813A4F\r\n\
:1023300048F48C2F0E948F2281118DC08C2F0E9417\r\n\
:10234000091BE3CF80E28C0F883048F4C77081E02E\r\n\
:1023500001C0880FCA95EAF70E944B1BD6CF8BE5C8\r\n\
:102360008C0F833078F4C53A29F0C63A31F482E80C\r\n\
:1023700090E005C081E890E002C083E890E0CF9152\r\n\
:102380000C94391088E58C0F833108F064C0C83A8A\r\n\
:1023900039F1C93A41F1CA3A49F1CB3A51F1CC3A53\r\n\
:1023A00059F1CD3A61F1C03B69F1CE3A71F1CF3AC2\r\n\
:1023B00079F1C13B81F1C23B89F1C33B91F1C43B4F\r\n\
:1023C00099F1C53BA1F1C63BA9F1C73BB1F1C83BAF\r\n\
:1023D000B9F1C93BC1F1CA3BC9F58AE292E038C004\r\n\
:1023E00082EE90E035C089EE90E032C08AEE90E057\r\n\
:1023F0002FC085EB90E02CC086EB90E029C087EBE6\r\n\
:1024000090E026C08CEC90E023C08DEC90E020C0E2\r\n\
:1024100083E891E01DC08AE891E01AC082E991E06A\r\n\
:1024200017C084E991E014C081E292E011C083E218\r\n\
:1024300092E00EC084E292E00BC085E292E008C018\r\n\
:1024400086E292E005C087E292E002C080E090E080\r\n\
:10245000CF910C944F10CF910895882309F44BC06D\r\n\
:10246000823859F40E94DD0F81FF45C089E30E9444\r\n\
:10247000091B0E94841B89E30CC0833871F40E94FD\r\n\
:10248000DD0F80FF38C083E50E94091B0E94841B7A\r\n\
:1024900083E50E942A1B0C94841B843859F40E9403\r\n\
:1024A000DD0F82FF28C087E40E94091B0E94841B65\r\n\
:1024B00087E4EFCF9CEF980F913A58F390E2980F92\r\n\
:1024C000983050F4877091E001C0990F8A95EAF72F\r\n\
:1024D000892F0E94511BDFCF9BE5980F933020F48A\r\n\
:1024E00080E090E00C943910885A833120F480E029\r\n\
:1024F00090E00C944F100895882321F00E944B1B0C\r\n\
:102500000C94841B0895882321F00E94511B0C9485\r\n\
:10251000841B0895CF92DF92EF92FF920F931F9347\r\n\
:10252000CF93DF93CDB7DEB728970FB6F894DEBF11\r\n\
:102530000FBECDBF8C0185E0F801DE011196019040\r\n\
:102540000D928A95E1F7F80140813181F280258171\r\n\
:1025500022952F7083819481892B31F03F3F31F494\r\n\
:1025600081E04F3F19F403C081E001C080E080FDAD\r\n\
:10257000C8C249833A8389819A812F830E94C71AEE\r\n\
:102580009E8388870E94C61A0E9499194E81E42F63\r\n\
:10259000E295EF70F0E0E05AFF4F2F8168850C94D0\r\n\
:1025A0002725842F807F142F1F70882311F0129508\r\n\
:1025B000107FFF2059F0112309F458C2812F68873A\r\n\
:1025C0000E945B1B0E94841B688550C2862F0E945C\r\n\
:1025D0002D12112309F495C2812F0E94611B2896A8\r\n\
:1025E0000FB6F894DEBF0FBECDBFDF91CF911F9124\r\n\
:1025F0000F91FF90EF90DF90CF900C94841B342FBD\r\n\
:10260000307F842F8F70303211F08295807F662367\r\n\
:1026100019F0613009F12AC0FF20A1F0222381F1D5\r\n\
:10262000213071F528960FB6F894DEBF0FBECDBFEE\r\n\
:10263000DF91CF911F910F91FF90EF90DF90CF909E\r\n\
:102640000C946B1B222319F0213009F45AC28E839B\r\n\
:102650000E946E1B8E818EC1FF2021F0263008F073\r\n\
:1026600050C20EC0253008F04CC284C1FF20C1F01A\r\n\
:10267000222331F0F801958190FFF8C19F70958376\r\n\
:1026800028960FB6F894DEBF0FBECDBFDF91CF9175\r\n\
:102690001F910F91FF90EF90DF90CF900C947C12E0\r\n\
:1026A000222309F467C1F6C1242F269526952370AD\r\n\
:1026B00030E02115310521F021303105C9F021C26A\r\n\
:1026C000FF2021F0862F942F937002C080E090E0CD\r\n\
:1026D00028960FB6F894DEBF0FBECDBFDF91CF9125\r\n\
:1026E0001F910F91FF90EF90DF90CF900C943910D5\r\n\
:1026F000FF2021F0862F942F937002C080E090E09D\r\n\
:1027000028960FB6F894DEBF0FBECDBFDF91CF91F4\r\n\
:102710001F910F91FF90EF90DF90CF900C944F108E\r\n\
:10272000862FFF2019F00E94EE1D02C00E94561E47\r\n\
:1027300028960FB6F894DEBF0FBECDBFDF91CF91C4\r\n\
:102740001F910F91FF90EF90DF90CF900C94DB1EC4\r\n\
:10275000842F837009F076C0F110D3C1262F229503\r\n\
:1027600026952770220F220F862F8F70C82ED12C0E\r\n\
:10277000E12CF12C022E04C0CC0CDD1CEE1CFF1C45\r\n\
:102780000A94D2F764FF10C06FE070E080E090E040\r\n\
:1027900004C0660F771F881F991F2A95D2F760958E\r\n\
:1027A00070958095909503C060E070E0CB01242F78\r\n\
:1027B000269526952370422F50E042305105D1F0E6\r\n\
:1027C0004330510559F16C297D298E299F294130CB\r\n\
:1027D000510541F128960FB6F894DEBF0FBECDBF6C\r\n\
:1027E000DF91CF911F910F91FF90EF90DF90CF90ED\r\n\
:1027F0000C94BE196C297D298E299F2928960FB625\r\n\
:10280000F894DEBF0FBECDBFDF91CF911F910F9126\r\n\
:10281000FF90EF90DF90CF900C94D8190E94BE19D2\r\n\
:10282000C701B60128960FB6F894DEBF0FBECDBF24\r\n\
:10283000DF91CF911F910F91FF90EF90DF90CF909C\r\n\
:102840000C94A419FF2019F0842F817001C0869583\r\n\
:10285000882309F456C1262F229526952770220F2A\r\n\
:10286000220F862F8F70C82ED12CE12CF12C022E36\r\n\
:1028700004C0CC0CDD1CEE1CFF1C0A94D2F764FFD4\r\n\
:1028800010C06FE070E080E090E004C0660F771F3A\r\n\
:10289000881F991F2A95D2F760957095809590951D\r\n\
:1028A00003C060E070E0CB01242F269526952370AD\r\n\
:1028B000422F50E042305105D1F04330510559F1DB\r\n\
:1028C0006C297D298E299F294130510541F1289697\r\n\
:1028D0000FB6F894DEBF0FBECDBFDF91CF911F9131\r\n\
:1028E0000F91FF90EF90DF90CF900C94921A6C298B\r\n\
:1028F0007D298E299F2928960FB6F894DEBF0FBE3A\r\n\
:10290000CDBFDF91CF911F910F91FF90EF90DF909E\r\n\
:10291000CF900C94AC1A0E94921AC701B601289667\r\n\
:102920000FB6F894DEBF0FBECDBFDF91CF911F91E0\r\n\
:102930000F91FF90EF90DF90CF900C94781A603F4A\r\n\
:1029400049F118F4603E48F48CC0623F09F451C06C\r\n\
:10295000E0F1633F09F461C084C0162F1F70842F1B\r\n\
:102960008F71FF2021F00E94111A812F89CE0E94C1\r\n\
:10297000321A812F28960FB6F894DEBF0FBECDBF56\r\n\
:10298000DF91CF911F910F91FF90EF90DF90CF904B\r\n\
:102990000C948312FF20A9F0253008F0B2C0842FD8\r\n\
:1029A0008F7128960FB6F894DEBF0FBECDBFDF91B2\r\n\
:1029B000CF911F910F91FF90EF90DF90CF900C94EB\r\n\
:1029C000571A263008F09DC0EACFFF20A1F0842FCF\r\n\
:1029D0008F7128960FB6F894DEBF0FBECDBFDF9182\r\n\
:1029E000CF911F910F91FF90EF90DF90CF900C94BB\r\n\
:1029F000111AFF2061F3842F8F7128960FB6F89477\r\n\
:102A0000DEBF0FBECDBFDF91CF911F910F91FF9021\r\n\
:102A1000EF90DF90CF900C94321AFF2091F0842F2A\r\n\
:102A20008F7128960FB6F894DEBF0FBECDBFDF9131\r\n\
:102A3000CF911F910F91FF90EF90DF90CF900C946A\r\n\
:102A4000FC1928960FB6F894DEBF0FBECDBFDF91FC\r\n\
:102A5000CF911F910F91FF90EF90DF90CF900C944A\r\n\
:102A6000F219FF20A1F0222309F4B1CF862F289676\r\n\
:102A70000FB6F894DEBF0FBECDBFDF91CF911F918F\r\n\
:102A80000F91FF90EF90DF90CF900C94651122236F\r\n\
:102A900009F4B1CF862F28960FB6F894DEBF0FBE8B\r\n\
:102AA000CDBFDF91CF911F910F91FF90EF90DF90FD\r\n\
:102AB000CF900C942D124F70C8010E94641C289670\r\n\
:102AC0000FB6F894DEBF0FBECDBFDF91CF911F913F\r\n\
:102AD0000F91FF90EF90DF90CF900C941B194F70E7\r\n\
:102AE000C80128960FB6F894DEBF0FBECDBFDF91A8\r\n\
:102AF000CF911F910F91FF90EF90DF90CF900C94AA\r\n\
:102B0000671C28960FB6F894DEBF0FBECDBFDF91CD\r\n\
:102B1000CF911F910F91FF90EF90DF90CF9008958C\r\n\
:102B20000E94681B0E943D1B0E94841B0E9409207A\r\n\
:102B30000E94DB1E80E090E00E94391080E090E06F\r\n\
:102B40000C944F100E94581B0C9490150E94C71AA9\r\n\
:102B5000292F22952F7030E02C3031054CF42A308B\r\n\
:102B600031056CF4225031092230310590F407C050\r\n\
:102B70002C30310551F02F30310539F00AC0803E3C\r\n\
:102B800010F0803F31F481E0089593FB882780F9AD\r\n\
:102B9000089580E00895CF93DF9300D000D01F9276\r\n\
:102BA000CDB7DEB70F900F900F900F900F90DF9181\r\n\
:102BB000CF910895CF93DF9300D000D000D0CDB750\r\n\
:102BC000DEB726960FB6F894DEBF0FBECDBFDF91FD\r\n\
:102BD000CF9108951F93CF93DF93C0916B0116E0BF\r\n\
:102BE00080916C01C81799F0D0E01C9FF0011D9FE7\r\n\
:102BF000F00D1124E359FE4F4081518162817381B0\r\n\
:102C0000848195810E94DA152196C770E9CFDF9102\r\n\
:102C1000CF911F91089540919D0150919E01609127\r\n\
:102C20009F017091A0018091A1019091A2010C944B\r\n\
:102C3000DA15CF938091A20182958F7009F05FC061\r\n\
:102C400080919F01882309F45AC020916B01A091C3\r\n\
:102C50006C0160919D0170919E018091A001909105\r\n\
:102C6000A10131E06F3F09F030E0B32FC6E02A1731\r\n\
:102C700009F445C0009721F07F3F21F44B2F03C09A\r\n\
:102C800041E001C040E030E040FD35C0C29FF001AE\r\n\
:102C9000C39FF00D1124E359FE4F418174132BC0E3\r\n\
:102CA0004081641328C04281411125C04381548171\r\n\
:102CB0004817590710F441505109481B590B483C1B\r\n\
:102CC0005105C8F48091A2018F7080618093A201A8\r\n\
:102CD00086E0829FF001839FF00D1124EE58FE4F95\r\n\
:102CE00080818F70806180838DE991E00E948A12DB\r\n\
:102CF000CF910C94EA152F5F3F4F2770B8CFCF913B\r\n\
:102D00000895CF92DF92EF92FF920F931F93CF938C\r\n\
:102D1000DF93CDB7DEB762970FB6F894DEBF0FBE74\r\n\
:102D2000CDBF8C0185E0F801DE011D9601900D926A\r\n\
:102D30008A95E1F7D8014C9111965C911197129602\r\n\
:102D40006C9112971396ED90FC90149770919D01E1\r\n\
:102D5000E0919E012091A0013091A1012115310542\r\n\
:102D600031F0EF3F31F481E07F3F19F403C081E09F\r\n\
:102D700001C080E0B82FB170CB2E80FD6CC1D09027\r\n\
:102D80009F01DD2009F4F5C0F091A201E216F306DF\r\n\
:102D900038F0C701821B930B883C910548F09BC01B\r\n\
:102DA000209530952E0D3F1D283C310508F093C02D\r\n\
:102DB0008F2F807F09F052C0E51314C0741312C026\r\n\
:102DC000D62E61110FC0FF70F061F093A2010E9436\r\n\
:102DD0000B168DE991E00E948A128091A201F80100\r\n\
:102DE00085836CC1EF2831F05F3F31F481E04F3FC4\r\n\
:102DF00019F403C081E001C080E080FD03C081E0E0\r\n\
:102E0000862701C080E0F82FF170FF2E80FF1CC0E4\r\n\
:102E100080916B0120916C0136E0821709F428C182\r\n\
:102E200090E0389FF001399FF00D1124E359FE4FD7\r\n\
:102E30007181571306C07081471303C072816713F5\r\n\
:102E400003C001968770E9CFD62E662309F436C1F8\r\n\
:102E50008091A20181608093A20153C0E51308C054\r\n\
:102E6000741306C0611104C0D8011596FC93AEC05E\r\n\
:102E70004D875E878D859E856A8B0E94A6156A891F\r\n\
:102E8000882329F1D62E662311F12091A201822FE9\r\n\
:102E900082958F7090E002970CF460C080919D0144\r\n\
:102EA00090919E0198878F831986FB86EA862C87EE\r\n\
:102EB000CE01079651C0E51731F14D875E878D85AC\r\n\
:102EC0009E856A8B0E94A6156A8981112EC0C80151\r\n\
:102ED0000E948A12A4C08F2F807F69F77E2DF98A05\r\n\
:102EE000E88A89890E94CB158DE991E00E948A12B7\r\n\
:102EF000EDE9F1E086E0DF011D928A95E9F70E9495\r\n\
:102F00000B16D12CDBC07413D8CF6111D6CFD801EA\r\n\
:102F10001596FC93C8010E948A12EDE9F1E086E063\r\n\
:102F2000DF011D928A95E9F7C9C0D62E662379F292\r\n\
:102F30002091A201822F82958F7090E0029774F009\r\n\
:102F400080919D0190919E019A8389831B82FD82CD\r\n\
:102F5000EC822E83CE0101960E948A1286E0F8014F\r\n\
:102F6000ADE9B1E001900D928A95E1F70E94191642\r\n\
:102F70006FC0E216F30628F0C701821B930B9C0179\r\n\
:102F800004C0209530952E0D3F1D283C310508F0DA\r\n\
:102F900052C0D62E662309F49ACFE5132CC07413C1\r\n\
:102FA0002AC08091A20180FD1DC0982F92959F702C\r\n\
:102FB000C9F0D80115968C9315979F3039F09F5F13\r\n\
:102FC0009295907F8F70892B15968C93C8010E94E3\r\n\
:102FD0008A1286E0F801ADE9B1E001900D928A9580\r\n\
:102FE000E1F736C086E0F801ADE9B1E001900D925D\r\n\
:102FF0008A95E1F763C04D875E878D859E850E9427\r\n\
:10300000A615882379F086E0F801ADE9B1E00190DA\r\n\
:103010000D928A95E1F70E9419160E940B16DD2485\r\n\
:10302000D3944CC08091A20181608093A201C80119\r\n\
:103030000E948A1243C07E2DF98AE88A89890E94FB\r\n\
:10304000CB15EDE9F1E086E0DF011D928A95E9F705\r\n\
:103050000E940B1633C0662309F439CF4D875E8773\r\n\
:103060008D859E850E94A615882309F430CFCBCF8D\r\n\
:103070004D875E878D859E850E94C71A292F2295D0\r\n\
:103080002F7030E0223031052CF49F7041F0811117\r\n\
:1030900006C00CC0243031052CF49F7049F4805ECA\r\n\
:1030A000883020F0C8010E948A12CF2CDC2C06C088\r\n\
:1030B000D80115969C91907F91F7F8CF8D2D62964F\r\n\
:1030C0000FB6F894DEBF0FBECDBFDF91CF911F9139\r\n\
:1030D0000F91FF90EF90DF90CF9008951F93CF93C3\r\n\
:1030E000DF93CDB7DEB72C970FB6F894DEBF0FBED7\r\n\
:1030F000CDBF4F83588769877A878B879C87CE019E\r\n\
:1031000007960E9481168823C1F02F8138858A8511\r\n\
:103110009B85892B31F03F3F11F080E003C02F3FAA\r\n\
:10312000E1F781E0811147C04F81588569857A8533\r\n\
:103130008B859C850E94DA153EC086E0FE0137969D\r\n\
:10314000DE01119601900D928A95E1F7FF81E885E5\r\n\
:103150004A855B854115510531F0EF3F31F481E03F\r\n\
:10316000FF3F19F403C081E001C080E080FD23C06F\r\n\
:1031700020916C0130E0C901019687709927609118\r\n\
:103180006B0170E086179707F1F1F983EA835D839D\r\n\
:103190004C8396E0929FD001939FB00D1124A359C8\r\n\
:1031A000BE4FFE01319601900D929A95E1F7809302\r\n\
:1031B0006C010E94EA1516E080916B0190916C0100\r\n\
:1031C000891779F1189FC001112483599E4F0E94DD\r\n\
:1031D0008116882331F1E0916B011E9FF0011124CB\r\n\
:1031E000E359FE4F408151816281738184819581D1\r\n\
:1031F0000E94DA1580916B0190E001968770992703\r\n\
:1032000080936B01D9CF0E94A21510926C0110928D\r\n\
:103210006B01EDE9F1E086E0DF011D928A95E9F7A7\r\n\
:10322000CACF2C960FB6F894DEBF0FBECDBFDF918C\r\n\
:10323000CF911F910895EF92FF920F931F93CF9319\r\n\
:10324000DF93FC01009709F46DC0F12CEE24E394A8\r\n\
:10325000EF0121968491843740F4843008F053C004\r\n\
:10326000813081F0823021F15DC0853709F445C09D\r\n\
:10327000B0F19CE7980F903708F054C08F770E9408\r\n\
:103280002D1243C08F010E5F1F4FFE01849190E20B\r\n\
:10329000980F983050F48770FE2D01C0FF0F8A956B\r\n\
:1032A000EAF78F2F0E945B1B15C00E94651112C0A8\r\n\
:1032B0008F010E5F1F4FFE01849190E2980F9830AE\r\n\
:1032C00058F48770FE2D01C0FF0F8A95EAF78F2F03\r\n\
:1032D0000E94611BE80119C00E942D12FBCFCF0193\r\n\
:1032E0000296FE01C491CC2361F0EFE9FFE0319733\r\n\
:1032F000F1F700C00000C150F6CFCF010296FE01E9\r\n\
:10330000F490EC0102C00E9465118F2D882341F0DA\r\n\
:10331000EFE9FFE03197F1F700C000008150F6CFF0\r\n\
:10332000FE0196CFDF91CF911F910F91FF90EF900B\r\n\
:10333000089508956093A7017093A8018093A9014F\r\n\
:103340009093AA010C9490150F931F930091A701DD\r\n\
:103350001091A8012091A9013091AA01062B172BE9\r\n\
:10336000282B392B0093A7011093A8012093A901C2\r\n\
:103370003093AA011F910F910C9490150F931F93F6\r\n\
:103380000091A7011091A8012091A9013091AA01F3\r\n\
:1033900006231723282339230093A7011093A8019C\r\n\
:1033A0002093A9013093AA011F910F910C949015BD\r\n\
:1033B0000F931F930091A7011091A8012091A901DB\r\n\
:1033C0003091AA0106271727282739270093A7013C\r\n\
:1033D0001093A8012093A9013093AA011F910F9186\r\n\
:1033E0000C9490151092A3011092A4011092A501C3\r\n\
:1033F0001092A6010C94901541E050E060E070E05E\r\n\
:1034000004C0440F551F661F771F8A95D2F740935B\r\n\
:10341000A3015093A4016093A5017093A6010C949D\r\n\
:10342000901541E050E060E070E004C0440F551F8B\r\n\
:10343000661F771F8A95D2F78091A3019091A4010E\r\n\
:10344000A091A501B091A601842B952BA62BB72B9B\r\n\
:103450008093A3019093A401A093A501B093A6012A\r\n\
:103460000C94901541E050E060E070E004C0440F1F\r\n\
:10347000551F661F771F8A95D2F740955095609526\r\n\
:1034800070958091A3019091A401A091A501B091A4\r\n\
:10349000A60184239523A623B7238093A3019093A9\r\n\
:1034A000A401A093A501B093A6010C94901541E04E\r\n\
:1034B00050E060E070E004C0440F551F661F771FA6\r\n\
:1034C0008A95D2F78091A3019091A401A091A501C2\r\n\
:1034D000B091A60184279527A627B7278093A3013B\r\n\
:1034E0009093A401A093A501B093A6010C9490150C\r\n\
:1034F0000F931F930091A3011091A4012091A501A6\r\n\
:103500003091A601062B172B282B392B0093A301F2\r\n\
:103510001093A4012093A5013093A6011F910F9150\r\n\
:103520000C9490150F931F930091A3011091A40187\r\n\
:103530002091A5013091A6010623172328233923C2\r\n\
:103540000093A3011093A4012093A5013093A60139\r\n\
:103550001F910F910C9490150F931F930091A3014D\r\n\
:103560001091A4012091A5013091A60106271727EB\r\n\
:10357000282739270093A3011093A4012093A501C4\r\n\
:103580003093A6011F910F910C9490150895CF923E\r\n\
:10359000DF92EF92FF920F931F93CF93DF93EC0193\r\n\
:1035A000C090A701D090A801E090A901F090AA01D5\r\n\
:1035B0008091A3019091A401A091A501B091A601D1\r\n\
:1035C000C82AD92AEA2AFB2A0FE110E0B701A6018E\r\n\
:1035D000002E04C076956795579547950A94D2F7C3\r\n\
:1035E00040FF07C0BE01802F0E94AA1B81309105B9\r\n\
:1035F00039F40150110950F7BE0180E00E94AA1B66\r\n\
:10360000DF91CF911F910F91FF90EF90DF90CF90BE\r\n\
:10361000089540910B0150910C0120E030E09FEFA4\r\n\
:10362000FA01E20FF31F6281681799F09F3F19F4C6\r\n\
:10363000611101C0922F2F5F3F4F2630310581F776\r\n\
:103640009F3F39F0FA01E90FF11D97FDFA9582834A\r\n\
:103650000895089540910B0150910C0120E030E055\r\n\
:10366000FA01E20FF31F9281981301C012822F5FBB\r\n\
:103670003F4F26303105A1F7089581E090E0E091B9\r\n\
:103680000B01F0910C01E80FF91F108201968830B0\r\n\
:103690009105A9F708959091B501982B9093B501E4\r\n\
:1036A000089580959091B50198239093B501089560\r\n\
:1036B0001092B50108959091B401982B9093B401A4\r\n\
:1036C000089580959091B40198239093B401089542\r\n\
:1036D0001092B40108958093AB0108951092AB014C\r\n\
:1036E000089540910B0150910C0120E030E080E002\r\n\
:1036F000FA01E20FF31F918191118F5F2F5F3F4F0E\r\n\
:1037000027303105A9F70895E0910B01F0910C01E4\r\n\
:103710008091B5018083E0910B01F0910C018081D3\r\n\
:103720009091B401892B80839091AB01992361F032\r\n\
:10373000E0910B01F0910C018081892B80830E9424\r\n\
:10374000711B81111092AB0180910B0190910C01C2\r\n\
:103750000C94E90F0E94680690E4980F903218F4D8\r\n\
:103760000E947A0608958D3B60F4883A10F5853AF8\r\n\
:10377000B8F4843090F4813009F05DC021E030E08D\r\n\
:10378000A1C0803E08F457C0883E38F0803F08F45E\r\n\
:1037900052C0282F30E0306595C0282F30E092C00D\r\n\
:1037A000853A09F44BC0863A09F04BC022E830E470\r\n\
:1037B00089C0883A09F448C0893A09F448C08A3A6D\r\n\
:1037C00009F448C08B3A09F448C08C3A09F448C05F\r\n\
:1037D0008B3B09F448C08C3B09F448C08D3A09F48E\r\n\
:1037E00048C0803B09F448C08E3A09F448C08F3A7B\r\n\
:1037F00009F448C0813B09F448C0823B09F448C041\r\n\
:10380000833B09F448C0843B09F448C0853B09F474\r\n\
:1038100048C0863B09F448C0873B09F448C0883B50\r\n\
:1038200009F448C0893B09F448C08A3B09F048C004\r\n\
:103830002AE236E447C020E030E044C021E830E42A\r\n\
:1038400041C023E830E43EC022EE34E43BC029EE20\r\n\
:1038500034E438C02AEE34E435C025EB34E432C019\r\n\
:1038600026EB34E42FC023EB34E42CC024EB34E407\r\n\
:1038700029C027EB34E426C02CEC34E423C02DEC23\r\n\
:1038800034E420C023E835E41DC02AE835E41AC03A\r\n\
:1038900022E935E417C024E935E414C021E236E416\r\n\
:1038A00011C023E236E40EC024E236E40BC025E268\r\n\
:1038B00036E408C026E236E405C027E236E402C05A\r\n\
:1038C00020E034E4C901089580E090E0089508956F\r\n\
:1038D000909333018093320108958295982F9C7CB8\r\n\
:1038E00096959695837344E0849F90011124922BC2\r\n\
:1038F000892F8A7A86959575990F892B08958091DD\r\n\
:10390000CB01843009F11092B70120E488E190E006\r\n\
:103910000FB6F894A895809360000FBE20936000C6\r\n\
:1039200083B7817F846083BF83B7816083BF7894CE\r\n\
:10393000889583B78E7F83BF88E10FB6F894809314\r\n\
:103940006000109260000FBE089508950895CF930F\r\n\
:103950000E94A51C0E94C6050E94A61CC0E08C2FD8\r\n\
:103960000E941706811105C0CF5FCE30C1F780E0FD\r\n\
:1039700001C081E0CF9108950C94A2151F920F927F\r\n\
:103980000FB60F9211248F939F93AF93BF938091A3\r\n\
:10399000B701811113C08091B8019091B901A09134\r\n\
:1039A000BA01B091BB014196A11DB11D8093B80130\r\n\
:1039B0009093B901A093BA01B093BB01BF91AF91AD\r\n\
:1039C0009F918F910F900FBE0F901F90189582E0DE\r\n\
:1039D00084BD93E095BD9AEF97BD80936E000895E6\r\n\
:1039E0002FB7F8948091B8019091B901A091BA01D4\r\n\
:1039F000B091BB012FBF0895CF92DF92EF92FF925B\r\n\
:103A00000F931F932FB7F8944091B8015091B901CB\r\n\
:103A10006091BA017091BB012FBF6A017B01EE2456\r\n\
:103A2000FF248C0120E030E0C016D106E206F30648\r\n\
:103A300010F441505109481B590BCA011F910F91B5\r\n\
:103A4000FF90EF90DF90CF9008951F920F920FB6E6\r\n\
:103A50000F9211248F939F93AF93BF938091B801DE\r\n\
:103A60009091B901A091BA01B091BB010196A11D3D\r\n\
:103A7000B11D8093B8019093B901A093BA01B0939E\r\n\
:103A8000BB01BF91AF919F918F910F900FBE0F908F\r\n\
:103A90001F9018950E94010DF8942FEF87EA91E688\r\n\
:103AA000215080409040E1F700C0000087E090EB9B\r\n\
:103AB000DC018093D4019093D501A093D601B093FB\r\n\
:103AC000D7012CE088E190E00FB6F894A895809398\r\n\
:103AD00060000FBE20936000FFCF8091BE0180FF89\r\n\
:103AE0000BC06091100185E0689FB00111247595AD\r\n\
:103AF0006795759567952AC081FF09C0609110018F\r\n\
:103B000085E0689FB0011124759567951FC082FFFD\r\n\
:103B100007C06091100185E0689FB001112416C0B4\r\n\
:103B20004091BF014423C9F060910F01461788F707\r\n\
:103B30002091100185E0289F90011124429FC0012F\r\n\
:103B4000439F900D112470E00E9413256038710589\r\n\
:103B500040F46115710539F002C065E070E0862F10\r\n\
:103B600008958FE7089581E008958091BE0180FF58\r\n\
:103B700008C060910E0170E0759567957595679521\r\n\
:103B800021C081FF06C060910E0170E075956795B8\r\n\
:103B900019C082FF04C060910E0170E010C08091D6\r\n\
:103BA000BF018823C1F060910D018617A0F79091A5\r\n\
:103BB0000E01989FC001112470E00E941325603807\r\n\
:103BC000710528F46115710521F0862F08958FE79E\r\n\
:103BD000089581E0089561E070E0F4CF803F21F422\r\n\
:103BE0000E946D1D819504C0813F29F40E946D1DC6\r\n\
:103BF0008093C2010895823F21F40E946D1D81953A\r\n\
:103C000004C0833F29F40E946D1D8093C101089573\r\n\
:103C1000893F19F40E94B51D05C08A3F31F40E9406\r\n\
:103C2000B51D81958093C30108958B3F21F40E94B7\r\n\
:103C3000B51D819504C08C3F29F40E94B51D809369\r\n\
:103C4000C4010895843F21F48091C001816017C0B0\r\n\
:103C5000853F21F48091C001826011C0863F21F42C\r\n\
:103C60008091C00184600BC0873F21F48091C00126\r\n\
:103C7000886005C0883F31F48091C00180618093E5\r\n\
:103C8000C00108958D3F21F48091BE0181600BC079\r\n\
:103C90008E3F21F48091BE01826005C08F3F29F4E0\r\n\
:103CA0008091BE0184608093BE010895803F39F405\r\n\
:103CB0008091C20187FF6CC01092C20169C0813F30\r\n\
:103CC00029F48091C2011816BCF362C09091C10121\r\n\
:103CD000823F29F497FF5CC01092C10159C0833F15\r\n\
:103CE00019F41916CCF354C0893F41F48091C301F3\r\n\
:103CF00018160CF04DC01092C3014AC08A3F29F437\r\n\
:103D00008091C30187FF44C0F6CF8B3F39F4809187\r\n\
:103D1000C40187FF3DC01092C4013AC08C3F29F412\r\n\
:103D20008091C4011816BCF333C0843F21F4809104\r\n\
:103D3000C0018E7F17C0853F21F48091C0018D7F27\r\n\
:103D400011C0863F21F48091C0018B7F0BC0873F5B\r\n\
:103D500021F48091C001877F05C0883F31F48091B4\r\n\
:103D6000C0018F7E8093C00113C08D3F21F48091EC\r\n\
:103D7000BE018E7F0BC08E3F21F48091BE018D7FEE\r\n\
:103D800005C08F3F29F48091BE018B7F8093BE01D7\r\n\
:103D90008091C10181110EC08091C20181110AC0C0\r\n\
:103DA0008091C301811106C08091C401811102C0BC\r\n\
:103DB0001092BF0108958091B60183FF7EC088E90B\r\n\
:103DC00093E00E9414058091C0011F928F9383E9B4\r\n\
:103DD00093E09F938F930E94AD0581E993E00E9449\r\n\
:103DE00014052091C101822F992787FD90959F93FB\r\n\
:103DF0002F938EE893E09F938F930E94AD058CE8FC\r\n\
:103E000093E00E9414052091C201822F992787FD1B\r\n\
:103E100090959F932F9389E893E09F938F930E94AF\r\n\
:103E2000AD0587E893E00E9414052091C301822F1D\r\n\
:103E3000992787FD90959F932F9384E893E09F9314\r\n\
:103E40008F930E94AD0582E893E00E9414052091B3\r\n\
:103E5000C401822F992787FD90959F932F938FE719\r\n\
:103E600093E09F938F930E94AD058CE793E00E94AF\r\n\
:103E700014058091BF011F928F9389E793E09F9370\r\n\
:103E80008F930E94AD0587E793E00E94140580910F\r\n\
:103E9000BE011F928F9384E793E09F938F930E94BC\r\n\
:103EA000AD0581E793E00E9414058DB79EB74C964F\r\n\
:103EB0000FB6F8949EBF0FBE8DBF80EC91E00E94BC\r\n\
:103EC0002E100E94F01C9093BD018093BC010895B8\r\n\
:103ED0001F93CF93DF938091BC019091BD010E940D\r\n\
:103EE000FC1C4091BF01442321F02091110130E0DE\r\n\
:103EF00006C0209112015AE0259F900111248217DB\r\n\
:103F0000930708F482C08091C1011091C201D09141\r\n\
:103F1000C301C091C401811107C0111105C0D111A5\r\n\
:103F200003C0CC2309F471C04F3F19F04F5F409399\r\n\
:103F3000BF01181624F40E946D1D8093C101809169\r\n\
:103F4000C10187FF05C00E946D1D81958093C1014D\r\n\
:103F5000111624F40E946D1D8093C2018091C2014C\r\n\
:103F600087FF05C00E946D1D81958093C2016091FD\r\n\
:103F7000C101662339F11091C201112319F177278C\r\n\
:103F800067FD7095872F972F0E94182423E333E352\r\n\
:103F900043E35FE30E947C240E94E5236093C10118\r\n\
:103FA000612F772767FD7095872F972F0E94182420\r\n\
:103FB00023E333E343E35FE30E947C240E94E52391\r\n\
:103FC0006093C2011D1624F40E94B51D8093C301A5\r\n\
:103FD0008091C30187FF05C00E94B51D8195809324\r\n\
:103FE000C3011C1624F40E94B51D8093C401809166\r\n\
:103FF000C40187FF05C00E94B51D81958093C4014F\r\n\
:10400000DF91CF911F910C94DB1EDF91CF911F9117\r\n\
:104010000895E0ECF1E085E0DF011D928A95E9F773\r\n\
:104020001092BF011092BE0108958BEB95E00E94A3\r\n\
:1040300014051F9281E08F931F9285E08F938DE688\r\n\
:1040400095E09F938F930E94AD050F900F900F9076\r\n\
:104050000F900F900F9008958330E9F128F481308C\r\n\
:1040600061F0823009F10895853009F462C008F4E6\r\n\
:1040700049C0863009F474C0089520911201862F3A\r\n\
:1040800090E0820F911D8F3F910520F4620F6093A5\r\n\
:10409000120103C08FEF80931201809112011F92D1\r\n\
:1040A0008F9386EA94E072C020911101862F90E0F0\r\n\
:1040B000820F911D8F3F910520F4620F60931101D3\r\n\
:1040C00003C08FEF80931101809111011F928F9394\r\n\
:1040D00084E994E05BC020911001862F90E0820F6C\r\n\
:1040E000911D8F3F910520F4620F6093100103C072\r\n\
:1040F0008FEF80931001809110011F928F9381E8C0\r\n\
:1041000094E044C020910F01862F90E0820F911D12\r\n\
:104110008F3F910520F4620F60930F0103C08FEF72\r\n\
:1041200080930F0180910F011F928F938CE694E092\r\n\
:104130002DC020910E01862F90E0820F911D8F3FA0\r\n\
:10414000910520F4620F60930E0103C08FEF8093FE\r\n\
:104150000E0180910E011F928F9383E594E016C0AB\r\n\
:1041600020910D01862F90E0820F911D8F3F9105C8\r\n\
:1041700020F4620F60930D0103C08FEF80930D0157\r\n\
:1041800080910D011F928F9388E394E09F938F930A\r\n\
:104190000E94AD050F900F900F900F9008958330FF\r\n\
:1041A00081F128F4813059F08230D1F008958530C2\r\n\
:1041B00009F449C0B8F1863009F456C008958091D9\r\n\
:1041C0001201681720F4861B8093120102C010921E\r\n\
:1041D0001201809112011F928F9389E294E054C0E2\r\n\
:1041E00080911101681720F4861B8093110102C091\r\n\
:1041F00010921101809111011F928F9387E194E039\r\n\
:1042000043C080911001681720F4861B8093100131\r\n\
:1042100002C010921001809110011F928F9384E0D0\r\n\
:1042200094E032C080910F01681720F4861B8093C0\r\n\
:104230000F0102C010920F0180910F011F928F9306\r\n\
:104240008FEE93E021C080910E01681720F4861B49\r\n\
:1042500080930E0102C010920E0180910E011F92F8\r\n\
:104260008F9386ED93E010C080910D01681720F4C4\r\n\
:10427000861B80930D0102C010920D0180910D01EB\r\n\
:104280001F928F938BEB93E09F938F930E94AD05CA\r\n\
:104290000F900F900F900F900895CF93C82F1F92FB\r\n\
:1042A0008F9320EC36E03F932F930E94AD0561E0A1\r\n\
:1042B00070E080E090E004C0660F771F881F991FB0\r\n\
:1042C000CA95D2F70E949A190F900F900F900F90F5\r\n\
:1042D000CF910C94A215CF93873288F58E3108F0D8\r\n\
:1042E0000EC18E3009F486C0D8F4873009F460C05E\r\n\
:1042F0008B3009F44FC0863009F005C18091B601BA\r\n\
:10430000817F8E7F8093B60185EC96E00E94140534\r\n\
:104310008FE799E00E94140581E08093C60146C0B2\r\n\
:10432000863109F4ADC020F4803109F478C0EBC0C7\r\n\
:10433000893109F48EC08B3109F449C0E4C0883357\r\n\
:1043400049F150F4893209F4D8C0853309F4D5C055\r\n\
:10435000873209F0D8C0D1C0833409F4CEC028F424\r\n\
:104360008A3308F4D0C08953CBC0883409F0CBC05D\r\n\
:104370000E94A2158EE699E00E9414052FEF83EDAE\r\n\
:1043800090E3215080409040E1F700C000000E947F\r\n\
:104390004A1D0CC08CEE96E03FC085E599E00E9476\r\n\
:1043A00014058091B60181608093B601C1E0B0C070\r\n\
:1043B0008091B601C82FC17080FFEFCF82E699E0EF\r\n\
:1043C0000E9414058091B601817F8E7F3CC0809150\r\n\
:1043D000B60181FBCC27C0F991E0C927C0FB81F968\r\n\
:1043E0008093B601CC2319F088E499E027C08AE3D2\r\n\
:1043F00099E012C08091B60182FBCC27C0F991E010\r\n\
:10440000C927C0FB82F98093B601CC2319F08BE257\r\n\
:1044100099E014C08BE199E00E941405C7CF809108\r\n\
:10442000B60183FBCC27C0F991E0C927C0FB83F913\r\n\
:104430008093B601CC2351F08FE099E00E941405DF\r\n\
:104440008091B60181608093B60162C082E099E0FC\r\n\
:10445000E3CF83EF98E00E9414058EEC98E00E9471\r\n\
:10446000140587E898E00E9414058AE598E00E9408\r\n\
:10447000140585E198E00E94140587EE97E0CCCF03\r\n\
:1044800089ED97E00E9414050E94DD0F1F928F9323\r\n\
:104490008FEB97E09F938F930E94AD0580910A0167\r\n\
:1044A0001F928F9388EA97E09F938F930E94AD05A8\r\n\
:1044B000809155011F928F9385E997E09F938F9389\r\n\
:1044C0000E94AD058091B8019091B901A091BA0107\r\n\
:1044D000B091BB01BF93AF939F938F9381E897E017\r\n\
:1044E0009F938F930E94AD058DB79EB742960FB6EE\r\n\
:1044F000F8949EBF0FBE8DBF59CF80E001C08D5193\r\n\
:104500000E944D2153CF8FE797E00E941405C0E031\r\n\
:104510008C2FCF91089580E0089580E00895CF9387\r\n\
:10452000C82F8091C601813081F020F0823009F4DB\r\n\
:104530004CC043C1A0910B01B0910C018C918E3005\r\n\
:1045400069F0873009F03BC109C0A0910B01B0911F\r\n\
:104550000C018C918E3011F0873049F48C2F0E9421\r\n\
:104560008B2281112FC08C2F0E946B212CC08C2F8D\r\n\
:104570000E948D22811126C0C431E1F070F4CB304D\r\n\
:1045800081F0C031D1F40E94152088EB96E00E94A2\r\n\
:10459000140582E08093C60115C0C93259F0C833B2\r\n\
:1045A00061F485EC96E00E9414058CEB96E00E9485\r\n\
:1045B000140508C01092C60104C186EB96E00E9463\r\n\
:1045C0001405FFC081E08170FEC0C43228F5CE31F1\r\n\
:1045D00008F0C1C0CB30A1F1D0F4C73009F0D3C08E\r\n\
:1045E0008EE18093120182E3809311018AE080932F\r\n\
:1045F000100184E180930F0188E080930E0188E22E\r\n\
:1046000080930D018CE595E00E941405BFC0C33175\r\n\
:1046100049F1C431C1F0B7C0CB3409F4A9C028F4C2\r\n\
:10462000C93289F0C83361F0AEC0C13509F49EC00B\r\n\
:10463000C23509F499C0CE3409F0A5C06AE09EC025\r\n\
:104640000E941520A3C08091C501882319F0109203\r\n\
:10465000C5019CC089E695E00E94140581E0809325\r\n\
:10466000C601B1C083E495E00E94140581E395E0A2\r\n\
:104670000E941405809112011F928F938EE295E0A3\r\n\
:104680009F938F930E94AD058CE295E00E941405E4\r\n\
:104690008AE195E00E941405809111011F928F9389\r\n\
:1046A00087E195E09F938F930E94AD0585E195E0AA\r\n\
:1046B0000E94140586E095E00E9414058091100187\r\n\
:1046C0001F928F9383E095E09F938F930E94AD0597\r\n\
:1046D00081E095E00E94140580EF94E00E941405AB\r\n\
:1046E00080910F011F928F938DEE94E09F938F9393\r\n\
:1046F0000E94AD058BEE94E00E94140586ED94E0D7\r\n\
:104700000E94140580910E011F928F9383ED94E017\r\n\
:104710009F938F930E94AD0581ED94E00E94140554\r\n\
:104720008AEB94E00E94140580910D011F928F93F3\r\n\
:1047300087EB94E09F938F930E94AD0585EB94E007\r\n\
:104740000E9414058DB79EB748960FB6F8949EBF89\r\n\
:104750000FBE8DBF1BC0CE51EC2FF0E0E95DFE4FC8\r\n\
:1047600080818093C50112C061E003C061E006C092\r\n\
:104770006AE08091C5010E942C2008C08091C5018B\r\n\
:104780000E94CF2003C08AE595E013C08091C50147\r\n\
:10479000882369F01F928F9384E595E09F938F9310\r\n\
:1047A0000E94AD050F900F900F900F9004C081E50F\r\n\
:1047B00095E00E94140581E006C01092C60180E0D9\r\n\
:1047C00002C080E000CFCF91089504D06894B11169\r\n\
:1047D0008DC0089570D088F09F5790F0B92F992719\r\n\
:1047E000B751A0F0D1F0660F771F881F991F1AF0FC\r\n\
:1047F000BA95C9F712C0B13081F077D0B1E0089511\r\n\
:1048000074C0672F782F8827B85F39F0B93FCCF391\r\n\
:10481000869577956795B395D9F73EF490958095F1\r\n\
:10482000709561957F4F8F4F9F4F0895E89409C011\r\n\
:1048300097FB3EF490958095709561957F4F8F4FD3\r\n\
:104840009F4F9923A9F0F92F96E9BB279395F695E9\r\n\
:10485000879577956795B795F111F8CFFAF4BB0F67\r\n\
:1048600011F460FF1BC06F5F7F4F8F4F9F4F16C0CB\r\n\
:10487000882311F096E911C0772321F09EE8872F55\r\n\
:10488000762F05C0662371F096E8862F70E060E011\r\n\
:104890002AF09A95660F771F881FDAF7880F96958A\r\n\
:1048A000879597F9089557FD9058440F551F59F073\r\n\
:1048B0005F3F71F04795880F97FB991F61F09F3F0D\r\n\
:1048C00079F087950895121613061406551FF2CF36\r\n\
:1048D0004695F1DF08C0161617061806991FF1CF86\r\n\
:1048E00086957105610508940895E894BB276627AD\r\n\
:1048F0007727CB0197F908950BD078C069D028F0BD\r\n\
:104900006ED018F0952309F05AC05FC01124EECF85\r\n\
:10491000CADFA0F3959FD1F3950F50E0551F629F1A\r\n\
:10492000F001729FBB27F00DB11D639FAA27F00D08\r\n\
:10493000B11DAA1F649F6627B00DA11D661F829F2F\r\n\
:104940002227B00DA11D621F739FB00DA11D621F14\r\n\
:10495000839FA00D611D221F749F3327A00D611D31\r\n\
:10496000231F849F600D211D822F762F6A2F112413\r\n\
:104970009F5750408AF0E1F088234AF0EE0FFF1F66\r\n\
:10498000BB1F661F771F881F91505040A9F79E3F9D\r\n\
:10499000510570F014C0AACF5F3FECF3983EDCF3F2\r\n\
:1049A000869577956795B795F795E7959F5FC1F7DA\r\n\
:1049B000FE2B880F911D9695879597F9089597F985\r\n\
:1049C0009F6780E870E060E008959FEF80EC0895B5\r\n\
:1049D00000240A94161617061806090608950024DE\r\n\
:1049E0000A9412161306140605060895092E039458\r\n\
:1049F000000C11F4882352F0BB0F40F4BF2B11F4CC\r\n\
:104A000060FF04C06F5F7F4F8F4F9F4F0895991BCA\r\n\
:104A100079E004C0991F961708F0961B881F7A95B5\r\n\
:104A2000C9F78095089597FB072E16F4009407D0D8\r\n\
:104A300077FD09D00E942D2507FC05D03EF4909506\r\n\
:104A400081959F4F0895709561957F4F0895EE0F62\r\n\
:104A5000FF1F0590F491E02D0994AA1BBB1B51E1A7\r\n\
:104A600007C0AA1FBB1FA617B70710F0A61BB70BDE\r\n\
:104A7000881F991F5A95A9F780959095BC01CD0183\r\n\
:064A80000895F894FFCF39\r\n\
:104A86005E084F092C09F808C50801AC012808146E\r\n\
:104A96000A321E3F4D3620FE02B1027B025B02E760\r\n\
:104AA6000100021902320201020304050607080981\r\n\
:024AB6000000FE\r\n\
";
}
